Subject: [PATCH 25/37] remote: rename 'new' variables

From: Brandon Williams <[email-masked]>
Date: Mon, 29 Jan 2018 14:37:16 -0800

Rename C++ keyword in order to bring the codebase closer to being able
to be compiled with a C++ compiler.

Signed-off-by: Brandon Williams <[email-masked]>
---
 remote.c | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/remote.c b/remote.c
index 4e93753e1..6f79881f6 100644
--- a/remote.c
+++ b/remote.c
@@ -1970,12 +1970,12 @@ static void unmark_and_free(struct commit_list *list, unsigned int mark)
 int ref_newer(const struct object_id *new_oid, const struct object_id *old_oid)
 {
 	struct object *o;
-	struct commit *old, *new;
+	struct commit *old, *new_commit;
 	struct commit_list *list, *used;
 	int found = 0;
 
 	/*
 	 * Both new and old must be commit-ish and new is descendant of
 	 * old.  Otherwise we require --force.
 	 */
 	o = deref_tag(parse_object(old_oid), NULL, 0);
@@ -1986,17 +1986,17 @@ int ref_newer(const struct object_id *new_oid, const struct object_id *old_oid)
 	o = deref_tag(parse_object(new_oid), NULL, 0);
 	if (!o || o->type != OBJ_COMMIT)
 		return 0;
-	new = (struct commit *) o;
+	new_commit = (struct commit *) o;
 
-	if (parse_commit(new) < 0)
+	if (parse_commit(new_commit) < 0)
 		return 0;
 
 	used = list = NULL;
-	commit_list_insert(new, &list);
+	commit_list_insert(new_commit, &list);
 	while (list) {
-		new = pop_most_recent_commit(&list, TMP_MARK);
-		commit_list_insert(new, &used);
-		if (new == old) {
+		new_commit = pop_most_recent_commit(&list, TMP_MARK);
+		commit_list_insert(new_commit, &used);
+		if (new_commit == old) {
 			found = 1;
 			break;
 		}
@@ -1970,12 +1970,12 @@ static void unmark_and_free(struct commit_list *list, unsigned int mark)
 
 	/*
-	 * Both new and old must be commit-ish and new is descendant of
+	 * Both new_commit and old must be commit-ish and new_commit is descendant of
 	 * old.  Otherwise we require --force.
 	 */
-- 
2.16.0.rc1.238.g530d649a79-goog